@@ -16,8 +16,15 @@ class ComputeController:
         raise Exception(res.text)
 
     @verify_credentials
-    def create_url(self, name):
-        res = requests.get(f'{self.account.hq}/compute/deploy/{name}', headers=self.account.headers)
+    def compute_proxy(self, route: str, data: dict):
+        res = requests.post(f'{self.account.hq}/compute/proxy/{route}', json=data, headers=self.account.headers)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
+
+    @verify_credentials
+    def create_url(self, name: str):
+        res = requests.get(f'{self.account.hq}/compute/url/{name}', headers=self.account.headers)
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
